function [polar_galileo ] = kepler()  
% KEPLER Summary of this function goes here
%   Detailed explanation goes here

clc;
close all

[a, e, i, omega_gr, omega_kl, m_galileo]=RINEX_laden();

B=[a, e, rad2deg(i),rad2deg(omega_gr),rad2deg(omega_kl), m_galileo];     % Aufruf der Funktion fr Ausgangsdaten (Matrix): basic=[a, e, i, omega_gr, omega_kl, GM_n, v_omega_n];
%% Daten                                                                 % m_galileo...mittlere Anomalie zur Referenzepoche
n=length(B(3)); % berechnete Lnge der einzelnen Vektoren
g=ones(n,1);
GM=398600.44; % km/s   '' Gravitationskonstante der Erde
GM_n=GM*g;    % der vorhandene Wert '' wird in einen Vektor gepackt, da der Wert '' eine Konstante ist.
v_omega=2*pi/86164; %  rad/sec  Rotationsrate der Erde
v_omega_n=v_omega*g;    % Hier wird die Rotationsrate in einen eindimensionalen Vektor gepackt

d=[1500];  % Gre der Intervalle zwischen den Messungen zu den Satelliten [sec]

n0=sqrt(GM_n./(B(:,1).^3));  % mittlere Bewegung [rad/sec]

T=2*pi./n0;   % Umlaufzeit in Sekunden

T_galileo=floor(T(1)/d(1));      % Anzahl der Messungen zum Satelliten berechnet aus der Umlaufzeit und den Messabstnden
%% Daten fr Wettzell
Rw=[4075.53022;931.78130;4801.61819]; % Positionsvektor (Ortsvektor) von Wettzell im erdfesten System
lamda_w=atand(Rw(2)/Rw(1));           % geografische Lnge von Wettzell
phi_w=atand(Rw(3)/sqrt((Rw(1).^2)+(Rw(2).^2))); % geografische Breite von Wettzell
%%          
% mittlere Anomalie 'Mk'
for i=1:1:10*T_galileo+1    % hier kann die Anzahl der Umlufe gendert werden
     M_galileo(i)=B(:,6)+n0(1)*((i-1)*d(1));
     dt_galileo(i)=((i-1)*d(1));
end

% exzentrische Anomalie

   Ek=bahn(M_galileo,B(2));   % Kepler-Gleichung ist nicht in geschlossener Form nach Ek auflsbar. 
                                % Daher nutzen wir ein langsam konvergierendes
                                % Verfahren. Ek(n)=M+e*sin(Ek(n-1))  
                                % Startwert E0=M
% wahre Anomalie 'vk'

    vk_galileo=rad2deg(atan2(((sqrt(1-B(1,2)^2).*sin(Ek))./(1-B(1,2).*cos(Ek))),...
                  ((cos(Ek)-B(1,2))./(1-B(1,2).*cos(Ek)))));
%   vk_gps=2*atand(sqrt((1+B(1,2))./(1-B(1,2))).*tan(Ek./2)); % Formel siehe Wikipedia
   
% Abstand des Satelliten

    r_galileo=B(1,1)*(1-B(1,2)*cos(Ek));
    
% Orts- und Geschwindigkeitsvektor im Bahnsystem

    r_b_galileo=ort(r_galileo,vk_galileo);
   
    v_b_galileo=[-B(1,1)*n0(1)*sin(Ek).*B(1,1)./r_galileo;... 
              B(1,1)*n0(1)*sqrt(1-(B(1,2).^2))*cos(Ek)*B(1,1)./r_galileo;...
              zeros(1,length(Ek))];
    
% Rotation vom Bahnsystem ins raumfeste Inertialsystem

    r_i_galileo=rotation(B(1,4),B(1,3),B(1,5))*r_b_galileo;
  
% Rotation vom raumfesten Inertialsystem ins erdfeste System

    re_galileo=rotation_i_e(v_omega_n,r_i_galileo,dt_galileo);  % basic=[a, e, i, omega_gr, omega_kl, GM_n, v_omega_n];
    
% Berechnung der Lnge und Breite

    [phi,lamda,hoehe]=xyz2blh_uebung(re_galileo(1,:), re_galileo(2,:), re_galileo(3,:));
    lamda_galileo=rad2deg(lamda);
    phi_galileo=rad2deg(phi);
%     lamda_galileo=rad2deg(atan2(re_galileo(2,:),re_galileo(1,:))); 
%     phi_galileo=rad2deg(atan2(re_galileo(3,:),sqrt((re_galileo(1,:).^2)+(re_galileo(2,:).^2))));
    
% Transformation vom erdfesten System in das topozentrische System

    r_topo_galileo=topo(lamda_w,phi_w,Rw,re_galileo);
    
% Bestimmung der Polarkoordinaten P=[Az,z,s]'

    polar_galileo=polarkoordinaten(r_topo_galileo);
    
%% 2.Darstellung der Satellitenbahnen in 3D

%raumfestes System
[X,Y,Z]=sphere(36);  % Koordinaten fr eine Eiheitskugel

% Skalierung der Koordinaten auf die Gre der Erde
X=6378.137.*X;  
Y=6378.137.*Y;
Z=6356.752.*Z;
    
% Galileo
    figure;
    hold on
    plot3(r_i_galileo(1,:),r_i_galileo(2,:),r_i_galileo(3,:),'r')
    plot3([0;B(1,1)],[0;0],[0;0],'k')
    plot3([0;0],[0;B(1,1)],[0;0],'k')
    plot3([0;0],[0;0],[0;B(1,1)],'k')
    mesh(X,Y,Z,'FaceColor','blue','EdgeColor','black');
    grid on
    title('Satellitenbahn Galileo raumfest')
    xlabel('X-Koordinate [km]')
    ylabel('Y-Koordinate [km]')
    zlabel('Z-Koordiate [km]')
 
%% erdfestes System
    
% Galileo
    figure;
    hold on
    plot3(re_galileo(1,:),re_galileo(2,:),re_galileo(3,:),'r')
    plot3([0;B(1,1)],[0;0],[0;0],'k')   % Das hier sind die Koordinatenachsen
    plot3([0;0],[0;B(1,1)],[0;0],'k')
    plot3([0;0],[0;0],[0;B(1,1)],'k')
    mesh(X,Y,Z,'FaceColor','blue','EdgeColor','black');
    grid on
    title('Satellitenbahn Galileo erdfest')
    xlabel('X-Koordinate [km]')
    ylabel('Y-Koordinate [km]')
    zlabel('Z-Koordiate [km]')
     
%% 3. Darstellung der Ergebnisse als Ground tracks

    darstellung(phi_galileo,lamda_galileo,'Galileo');
    title('Ground Track Galileo')
    
%% 4. Sichtbarkeit der einzelnen Satelliten 

    Sichtbarkeit_galileo=sichtbarkeit(polar_galileo,dt_galileo);
    figure;
    hold on
    plot(Sichtbarkeit_galileo./3600,ones(length(Sichtbarkeit_galileo./3600)),'r')
   
    title ('Sichtbarkeit')
    hold off
    xlabel('Sichtbarkeit [h]')
    ylabel('GPS')
end